<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="am">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="69"/>
        <source>MX Repo Manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="549"/>
        <source>Select the APT repository that you want to use:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>መፈለጊያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>የ ዴቢያን ማጠራቀሚያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>ፈጣን የ ዴቢያን ማጠራቀሚያ ለ እኔ ምረጥልኝ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>እያንዳንዱ ምንጭ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>Display help </source>
        <translation>እርዳታ ማሳያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Help</source>
        <translation>እርዳታ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>About this application</source>
        <translation>ስለዚህ መተግበሪያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>About...</source>
        <translation>ስለ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>መተግበሪያ ማጥፊያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Close</source>
        <translation>መዝጊያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Apply</source>
        <translation>መፈጸሚያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="393"/>
        <location filename="../mainwindow.cpp" line="687"/>
        <source>Success</source>
        <translation>ተሳክቷል</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <location filename="../mainwindow.cpp" line="393"/>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>Lists</source>
        <translation>ዝርዝሮች</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="222"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>ምንጮች (የ ተመረመሩ ምንጮች እና አስችለዋል)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <location filename="../mainwindow.cpp" line="597"/>
        <location filename="../mainwindow.cpp" line="607"/>
        <location filename="../mainwindow.cpp" line="624"/>
        <location filename="../mainwindow.cpp" line="643"/>
        <location filename="../mainwindow.cpp" line="650"/>
        <location filename="../mainwindow.cpp" line="668"/>
        <location filename="../mainwindow.cpp" line="674"/>
        <location filename="../mainwindow.cpp" line="734"/>
        <source>Error</source>
        <translation>ስህተት</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>Could not change the repo.</source>
        <translation>ማጠራቀሚያ መቀየር  አልተቻለም</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source>Cancel</source>
        <translation>መሰረዣ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="423"/>
        <source>Please wait...</source>
        <translation>እባክዎን ይቆዩ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="464"/>
        <source>About %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="466"/>
        <source>Version: </source>
        <translation>እትም</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="467"/>
        <source>Program for choosing the default APT repository</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="469"/>
        <source>Copyright (c) MX Linux</source>
        <translation>የ ቅጂ መብት (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>%1 License</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>%1 Help</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="492"/>
        <source>Warning</source>
        <translation>ማስጠንቀቂያ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="493"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="551"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="597"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="607"/>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Could not detect fastest repo.</source>
        <translation>ፈጣን ማጠራቀሚያ ማግኘት አልተቻለም</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="643"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="650"/>
        <source>MX version not detected or out of range: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="668"/>
        <source>Could not download original APT files.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>Could not unzip downloaded file.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="683"/>
        <source>Enabling AHS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="683"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="688"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="734"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="41"/>
        <source>License</source>
        <translation>ፍቃድ</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <source>Cancel</source>
        <translation>መሰረዣ</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>&amp;መዝጊያ</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>Error</source>
        <translation>ስህተት</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>